@@ -1,5 +1,6 @@
-from src.sqlcarve.validator.validator import *
+from sqlcarve.validator.validator import *
 import logging as log
+import json as js
 
 
 def analyse(fichier, referencefile):
@@ -11,7 +12,7 @@ def analyse(fichier, referencefile):
         for stmnt in stmnt_list:
             dico = valid.validate(statement=stmnt, ref_statement=stmnt, ref_comments=referencefile, type="all")
 
-    print(dico)
+    print(js.dumps(dico, ensure_ascii=False, indent=2))
 
     log.info("End of validation")
 
