@@ -1,7 +1,7 @@
 import zipfile
 
 import sqlparse as parse
-from src.sqlcarve.validator.parser import SqlParser
+from sqlcarve.validator.parser import SqlParser
 import logging as log
 import sqlvalidator
 import json
